summaryrefslogtreecommitdiffstats
path: root/src/compositor/extensions/qwaylandxdgshell.cpp
diff options
context:
space:
mode:
authorJohan Klokkhammer Helsing <johan.helsing@qt.io>2016-07-13 16:55:34 +0200
committerJohan Helsing <johan.helsing@qt.io>2016-08-03 13:07:52 +0000
commita147fedc76c84d2a6b50820a685288efb43f80db (patch)
tree5d4af8751c7869bc943a069667af9517ed587cb2 /src/compositor/extensions/qwaylandxdgshell.cpp
parenta4d68e7d78a28225c23931431f0db6ebf75f5e41 (diff)
Rename createSurface and similar signals
* createSurface -> surfaceRequested * createXdgSurface -> xdgSurfaceRequested * createXdgPopup -> xdgPopupRequested * createShellSurface -> wlShellSurfaceRequested * shellSurfaceCreated -> wlShellSurfaceCreated Change-Id: I715a927242130d7504955002a6a64a2bac516d46 Reviewed-by: Giulio Camuffo <giulio.camuffo@kdab.com>
Diffstat (limited to 'src/compositor/extensions/qwaylandxdgshell.cpp')
-rw-r--r--src/compositor/extensions/qwaylandxdgshell.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/compositor/extensions/qwaylandxdgshell.cpp b/src/compositor/extensions/qwaylandxdgshell.cpp
index 8299bd4ce..96fc171d8 100644
--- a/src/compositor/extensions/qwaylandxdgshell.cpp
+++ b/src/compositor/extensions/qwaylandxdgshell.cpp
@@ -150,11 +150,11 @@ void QWaylandXdgShellPrivate::xdg_shell_get_xdg_surface(Resource *resource, uint
QWaylandResource xdgSurfaceResource(wl_resource_create(resource->client(), &xdg_surface_interface,
wl_resource_get_version(resource->handle), id));
- emit q->createXdgSurface(surface, xdgSurfaceResource);
+ emit q->xdgSurfaceRequested(surface, xdgSurfaceResource);
QWaylandXdgSurface *xdgSurface = QWaylandXdgSurface::fromResource(xdgSurfaceResource.resource());
if (!xdgSurface) {
// A QWaylandXdgSurface was not created in response to the createXdgSurface signal, so we
// create one as fallback here instead.
xdgSurface = new QWaylandXdgSurface(q, surface, xdgSurfaceResource);
}
@@ -196,11 +196,11 @@ void QWaylandXdgShellPrivate::xdg_shell_get_xdg_popup(Resource *resource, uint32
wl_resource_get_version(resource->handle), id));
QWaylandInputDevice *inputDevice = QWaylandInputDevice::fromSeatResource(seat);
QPoint position(x, y);
- emit q->createXdgPopup(surface, parentSurface, inputDevice, position, xdgPopupResource);
+ emit q->xdgPopupRequested(surface, parentSurface, inputDevice, position, xdgPopupResource);
QWaylandXdgPopup *xdgPopup = QWaylandXdgPopup::fromResource(xdgPopupResource.resource());
if (!xdgPopup) {
// A QWaylandXdgPopup was not created in response to the createXdgPopup signal, so we
// create one as fallback here instead.
xdgPopup = new QWaylandXdgPopup(q, surface, parentSurface, position, xdgPopupResource);
}
@@ -150,11 +150,11 @@ void QWaylandXdgShellPrivate::xdg_shell_get_xdg_surface(Resource *resource, uint
QWaylandXdgSurface *xdgSurface = QWaylandXdgSurface::fromResource(xdgSurfaceResource.resource());
if (!xdgSurface) {
- // A QWaylandXdgSurface was not created in response to the createXdgSurface signal, so we
+ // A QWaylandXdgSurface was not created in response to the xdgSurfaceRequested signal, so we
// create one as fallback here instead.
xdgSurface = new QWaylandXdgSurface(q, surface, xdgSurfaceResource);
@@ -196,11 +196,11 @@ void QWaylandXdgShellPrivate::xdg_shell_get_xdg_popup(Resource *resource, uint32
QWaylandXdgPopup *xdgPopup = QWaylandXdgPopup::fromResource(xdgPopupResource.resource());
if (!xdgPopup) {
- // A QWaylandXdgPopup was not created in response to the createXdgPopup signal, so we
+ // A QWaylandXdgPopup was not created in response to the xdgPopupRequested signal, so we
// create one as fallback here instead.
xdgPopup = new QWaylandXdgPopup(q, surface, parentSurface, position, xdgPopupResource);